Estimates the covariate-specific ROC curve (cROC) defined as
$$ROC(p|\mathbf{x}) = 1 - F_{D}\{F_{\bar{D}}^{-1}(1-p|\mathbf{x})|\mathbf{x}\},$$
where
$$F_{D}(y|\mathbf{x}) = Pr(Y_{D} \leq y | \mathbf{X}_{D} = \mathbf{x}),$$
$$F_{\bar{D}}(y|\mathbf{x}) = Pr(Y_{\bar{D}} \leq y | \mathbf{X}_{\bar{D}} = \mathbf{x}).$$
Note that, for the sake of clarity, we assume that the covariates of interest are the same in both healthy and diseased populations. In particular, the method implemented in this function estimates \(F_{D}(\cdot|\mathbf{x})\) and \(F_{\bar{D}}(\cdot|\mathbf{x})\) assuming a (semiparametric) location regression model for \(Y\) in each population separately, i.e.,
$$Y_{D} = \mathbf{X}_{D}^{T}\mathbf{\beta}_{D} + \sigma_{D}\varepsilon_{D},$$
$$Y_{\bar{D}} = \mathbf{X}_{\bar{D}}^{T}\mathbf{\beta}_{\bar{D}} + \sigma_{\bar{D}}\varepsilon_{\bar{D}},$$
such that the covariate-specific ROC curve can be expressed as
$$ROC(p|\mathbf{x}) = 1 - G_{D}\{a(\mathbf{x}) + b G_{\bar{D}}^{-1}(1-p)\},$$
where \(a(\mathbf{x}) = \mathbf{x}^{T}\frac{\mathbf{\beta}_{\bar{D}} - \mathbf{\beta}_{D}}{\sigma_{D}}\), \(b = \frac{\sigma_{\bar{D}}}{\sigma_{D}}\), and \(G_{D}\) and \(G_{\bar{D}}\) are the distribution functions of \(\varepsilon_{D}\) and \(\varepsilon_{\bar{D}}\), respectively. In line with the assumptions made about the distributions of \(\varepsilon_{D}\) and \(\varepsilon_{\bar{D}}\), estimators will be referred to as: (a) "normal", where Gaussian errors are assumed, i.e., \(G_{D}(y) = G_{\bar{D}}(y) = \Phi(y)\) (Faraggi, 2003); and, (b) "empirical", where no assumptios are made about the distribution (in this case, \(G_{D}\) and \(G_{\bar{D}}\) are empirically estimated on the basis of standardised residuals (Pepe, 1998)).
The covariate-specific area under the curve is
$$AUC(\mathbf{x})=\int_{0}^{1}ROC(p|\mathbf{x})dp.$$
When Gaussian errors are assumed, there is a closed-form expression for the covariate-specific AUC, which is used in the package. In contrast, when no assumptios are made about the distributionis of the errors, the integral is computed numerically using Simpson's rule. With regard to the partial area under the curve, when focus = "FPF" and assuming an upper bound \(u_1\) for the FPF, what it is computed is
$$pAUC_{FPF}(u_1|\mathbf{x})=\int_0^{u_1} ROC(p|\mathbf{x})dp.$$
Again, when Gaussian errors are assumed, there is a closed-form expression (Hillis and Metz, 2012). Otherwise, the integral is approximated numerically (Simpson's rule). The returned value is the normalised pAUC, \(pAUC_{FPF}(u_1|\mathbf{x})/u_1\) so that it ranges from \(u_1/2\) (useless test) to 1 (perfect marker). Conversely, when focus = "TPF", and assuming a lower bound for the TPF of \(u_2\), the partial area corresponding to TPFs lying in the interval \((u_2,1)\) is computed as
$$pAUC_{TPF}(u_2|\mathbf{x})=\int_{u_2}^{1}ROC_{TNF}(p|\mathbf{x})dp,$$
where \(ROC_{TNF}(p|\mathbf{x})\) is a \(270^\circ\) rotation of the ROC curve, and it can be expressed as\(ROC_{TNF}(p|\mathbf{x}) = F_{\bar{D}}\{F_{D}^{-1}(1-p|\mathbf{x})|\mathbf{x}\}=G_{\bar{D}}\{\frac{\mu_{D}(\mathbf{x})-\mu_{\bar{D}}(\mathbf{x})}{\sigma_{\bar{D}}(\mathbf{x})}+G_{D}^{-1}(1-p)\frac{\sigma_{D}(\mathbf{x})}{\sigma_{\bar{D}}(\mathbf{x})}\}.\) Again, when Gaussian errors are assumed, there is a closed-form expression (Hillis and Metz, 2012). Otherwise, the integral is approximated numerically (Simpson's rule). The returned value is the normalised pAUC, \(pAUC_{TPF}(u_2|\mathbf{x})/(1-u_2)\), so that it ranges from \((1-u_2)/2\) (useless test) to 1 (perfect test).