AROC.bnp and cROC.bnpThis function is used to set various parameters controlling the prior information to be used in the AROC.bnp and cROC.bnp functions.
priorcontrol.bnp(m0 = NA, S0 = NA, nu = NA, Psi = NA, a = 2, b = NA,
alpha = 1, L = 10)A list with components for each of the possible arguments.
A numeric vector. Hyperparameter; mean vector of the (multivariate) normal prior distribution for the mean of the normal component of the centring distribution. NA signals autoinitialization, with defaults: a vector, of length \(Q\), of zeros, if the data are standardised and the least squares estimates of the regression coefficients if the data are not standardised.
A numeric matrix. Hyperparameter; covariance matrix of the (multivariate) normal prior distribution for the mean of the normal component of the centring distribution. NA signals autoinitialization, with defaults: 10\(I_{Q\times Q}\) if the data are standardised and \(\mathbf{\hat{\Sigma}}\) if the data are not standardised, where \(\mathbf{\hat{\Sigma}}\) is the estimated covariance matrix of the regression coefficients obtained by fitting a linear model to the data.
A numeric value. Hyperparameter; degrees of freedom of the Wishart prior distribution for the precision matrix of the the normal component of the centring distribution.NA signals autoinitialization, with default: \(Q+2\) where \(Q\) is the number of columns of the design matrix.
A numeric matrix. Hyperparameter; scale matrix of the Wishart distribution for the precision matrix of the the normal component of the centring distribution. NA signals autoinitialization, with defaults: \(I_{Q\times Q}\) if the data are standardised and to 30\(\mathbf{\hat{\Sigma}}\) if the data are not standardised, where \(\mathbf{\hat{\Sigma}}\) is the estimated covariance matrix of the regression coefficients obtained by fitting a linear model to the data.
A numeric value. Hyperparameter; shape parameter of the gamma prior distribution for the precisions (inverse variances) of each component. The default is 2.
A numeric value. Hyperparameter; shape parameter of the gamma prior distribution for the precisions (inverse variances) of each component. NA signals autoinitialization, with defaults: 0.5 if the data are standardised and \(\frac{\hat{\sigma}^2}{2}\) if the data are not standardised
A numeric value. Precision parameter of the Dirichlet Process. The default is 1.
A numeric value. Upper bound on the number of mixture components. Setting L = 1 corresponds to a normal model. The default is 10.
AROC.bnp and cROC.bnp