pooledROC.dpmThis function is used to set various parameters controlling the prior information to be used in the pooledROC.dpm function.
priorcontrol.dpm(m0 = NA, S0 = NA, a = 2, b = NA, alpha = 1, L = 10)A list with components for each of the possible arguments.
A numeric value. Hyperparameter; mean of the normal prior distribution for the means of each component. NA signals autoinitialization, with defaults: 0 if the data are standardised and \(\bar{y}_d\) (\(d \in \{D, \bar{D}\}\) if the data are not standardised.
A numeric value. Hyperparameter; variance of the normal prior distribution for the means of each component. NA signals autoinitialization, with defaults: 10 if the data are standardised and 100*\(\frac{s^2_d}{n_d}\) (\(d \in \{D, \bar{D}\}\) if the data are not standardised, where \(s_d\) denotes the sample standard deviation.
A numeric value. Hyperparameter; shape parameter of the gamma prior distribution for the precisions (inverse variances) of each component. The default is 2.
A numeric value. Hyperparameter; rate parameter of the gamma prior distribution for the precisions (inverse variances) of each component. NA signals autoinitialization, with defaults: 0.5 if the data are standardised and \(\frac{s^2_d}{2}\) (\(d \in \{D, \bar{D}\}\) if the data are not standardised.
A numeric value. Precision parameter of the Dirichlet Process. The default is 1.
A numeric value. Upper bound on the number of mixture components. Setting L=1 corresponds to a normal model. The default is 10.
pooledROC.dpm